bib file to parse. By default, the file
REFERENCES.bib in the root directory of the package given by
the package argument is used.
package
package from which we want to read the bibliography.
Only used if file is unspecified.
Core R packages (base, datasets, graphics, grDevices, methods,
stats, stats4, tools and utils) are treated specially: this package
contains bibtex entries for these packages.
## this package has a REFERENCES.bib filebib <- read.bib(package = "bibtex")
## bibtex collects bibtex entries for R base packagesbase.bib <- read.bib(package = "base")