| write.bib | R Documentation |
Generates a Bibtex file from a bibentry object or a list of
packages. It is useful for adding relevant citations in Sweave documents.
write.bib(entry, file = "Rpackages.bib", append = FALSE, verbose = TRUE)
entry |
a |
file |
output Bibtex file. |
append |
logical. If |
verbose |
a logical to toggle verbosity. |
the list of Bibtex objects – invisibly.
Renaud Gaujoux, based on the function Rpackages.bib
from Achim Zeileis (see References).
[R] Creating bibtex file of all installed packages? Achim Zeileis. R-help mailing list.
tmp <- tempfile(fileext = ".bib")
write.bib(c("bibtex", "utils", "tools"), file = tmp)
bibs <- read.bib(tmp)
tmp2 <- tempfile(fileext = ".bib")
write.bib(bibs, tmp2)
unname(tools::md5sum(tmp) == tools::md5sum(tmp2))
unlink(c(tmp, tmp2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.